==> slick_browser-8.x-2.0-beta1.tar.gz: slick_browser/js/slick-browser.view.js <==
/**
 * @file
 * Provides Slick Browser view utilitiy functions.
 */

(function ($, Drupal) {

  'use strict';

  /**
   * Slick Browser utility functions.
   *
   * @param {int} i
   *   The index of the current element.
   * @param {HTMLElement} view
   *   The view HTML element.
   */
  function sbView(i, view) {
    var $view = $(view);

    /**
     * Build plain thumbnails for complex rendered entity for lits/table view.
     *
     * @param {int} j
     *   The index of the current element.
     * @param {HTMLElement} media
     *   The media HTML element.
     */
    function buildThumbnail(j, media) {
      var $media = $(media);
      var thumb = $media.data('thumb');

      if (thumb && !$('.media__thumbnail', media).length) {
        $media.append('<img src="' + thumb + '" alt="' + Drupal.t('Thumbnail') + '" class="media__thumbnail visible-list">');
        $media.addClass('media--list');
      }
    }

    // Add a contextual class that Slick browser is active.
    $view.closest('html').addClass('sb-html');

    // Pass the grid info into .grid__content.
    // $view.find('.grid__content').once('gridContent').each(sbGrid);
    // Replaces complex rendered entity with plain thumbnails for table view.
    $view.find('.media:not(.media--switch)').once('gridMedia').each(buildThumbnail);

    // After AJAX pager, add sb__main class to view parent element.
    if ($view.parent('div').length) {
      $view.closest('form').find('> div:not(.sb__header, .sb__footer)').addClass('sb__main');
    }
  }

  /**
   * Build the grid info extracted from exisiting elements.
   *
   * @param {int} j
   *   The index of the current element.
   * @param {HTMLElement} grid
   *   The grid HTML element.
   */
  function sbGrid(j, grid) {
    var $grid = $('.grid__content', grid);
    var previewHeight = 160;
    if (!$('.views-field', grid).length) {
      return;
    }

    window.setTimeout(function () {
      if ($('.views-field--preview', grid).length) {
        previewHeight = $(grid).height();
        $('.views-field--preview', grid).css('minHeight', previewHeight);
      }
    }, 1500);

    /**
     * Toggle the grid info.
     *
     * @param {jQuery.Event} event
     *   The event triggered by a `click` event.
     */
    function toggleGridInfo(event) {
      event.preventDefault();
      event.stopPropagation();

      var $activeGrid = $(event.target).closest('.grid');

      if ($('.views-field--preview', $activeGrid).length) {
        if ($('.media', $activeGrid).length) {
          $('.grid__content', $activeGrid).css('minHeight', previewHeight > 120 ? previewHeight + 12 : 160);
        }
      }

      $activeGrid.toggleClass('is-info-active');
      if (!$activeGrid.hasClass('is-info-active')) {
        $('.grid__content', $activeGrid).css('minHeight', '');
      }
    }

    // @todo fault proof.
    var $clone = $grid.find('.views-field:not(.views-field-entity-browser-select, .views-field--preview, .views-field--grid-hidden)').clone();

    $clone.each(function () {
      var $field = $(this);
      if ($field.find('.media, img, iframe').length) {
        $field.empty();
      }
    });

    // Remove the views-field class to avoid CSS override.
    // @todo $clone.removeClass('views-field').addClass('views-field--cloned');
    // Add a button to toggle the grid info.
    if (!$('.button-group--grid', grid).length) {
      $grid.append('<div class="button-group button-wrap button-group--grid is-button-js"><button class="button button--select" type="button">&#43;</button><button class="button button--info" type="button">?</button></div>');
    }
    // Append the new .grid__info element.
    // @todo if (!$('.grid__info', grid).length) {
    // @todo   $grid.append('<div class="grid__info visible-grid" />');
    // @todo }
    // @todo if (!$('.grid__info .views-field--cloned', grid).length) {
    // @todo $('.grid__info', grid).append($clone);
    // @todo }
    // Events.
    $grid.on('click.sbGridInfo', '.button--info', toggleGridInfo);
  }

  /**
   * Attaches Slick Browser view behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.slickBrowserView = {
    attach: function (context) {
      $('.view--sb', context).once('sbView').each(sbView);
      $('.grid', context).once('sbGrid').each(sbGrid);
    }
  };

})(jQuery, Drupal);

==> slick_browser-8.x-2.4-beta1.tar.gz: slick_browser/js/slick-browser.view.js <==
/**
 * @file
 * Provides Slick Browser view utilitiy functions.
 */

(function ($, Drupal) {

  'use strict';

  var _onView = 'view--sb--on';
  var _elView = '.view--sb:not(.' + _onView + ')';
  var _onGrid = 'sb-grid--on';
  var _elGrid = '.grid:not(.' + _onGrid + ')';
  var _onMedia = 'sb-media--on';
  var _elMedia = '.media:not(.' + _onMedia + '):not(.media--switch)';

  Drupal.slickBrowser = Drupal.slickBrowser || {};

  /**
   * Slick Browser utility functions.
   *
   * @param {HTMLElement} view
   *   The view HTML element.
   */
  function sbView(view) {
    var me = Drupal.slickBrowser;
    var $view = $(view);
    var $slick = $('.slick__slider', view);

    // Fixed for vertical direction cropped slide.
    if ($slick.length && !$slick.hasClass('slick-initialized')) {
      $slick.on('init.sb', function () {
        window.setTimeout(function () {
          $slick[0].slick.refresh();
        }, 500);
      });
    }

    /**
     * Build plain thumbnails for complex rendered entity for lits/table view.
     *
     * @param {HTMLElement} media
     *   The media HTML element.
     */
    function buildThumbnail(media) {
      var $media = $(media);
      var thumb = $media.data('thumb');

      if (thumb && !$('.media__thumbnail', media).length) {
        $media.append('<img src="' + thumb + '" alt="' + Drupal.t('Thumbnail') + '" class="media__thumbnail visible-list">');
        $media.addClass('media--list');
      }

      $media.addClass(_onMedia);
    }

    // Add a contextual class that Slick browser is active.
    $view.closest('html').addClass('sb-html');

    // Pass the grid info into .grid__content.
    // once('gridContent', '.grid__content', view).forEach(sbGrid);
    // Replaces complex rendered entity with plain thumbnails for table view.
    me.once(view, _elMedia, buildThumbnail);

    // After AJAX pager, add sb__main class to view parent element.
    if ($view.parent('div').length) {
      $view.closest('form').find('> div:not(.sb__header, .sb__footer)').addClass('sb__main');
    }

    $view.addClass(_onView);
  }

  /**
   * Build the grid info extracted from exisiting elements.
   *
   * @param {HTMLElement} grid
   *   The grid HTML element.
   */
  function sbGrid(grid) {
    var $grid = $('.grid__content', grid);
    var previewHeight = 160;
    if (!$('.views-field', grid).length) {
      return;
    }

    window.setTimeout(function () {
      if ($('.views-field--preview', grid).length) {
        previewHeight = $(grid).height();
        $('.views-field--preview', grid).css('minHeight', previewHeight);
      }
    }, 100);

    /**
     * Toggle the grid info.
     *
     * @param {jQuery.Event} event
     *   The event triggered by a `click` event.
     */
    function toggleGridInfo(event) {
      event.preventDefault();
      event.stopPropagation();

      var $activeGrid = $(event.target).closest('.grid');

      if ($('.views-field--preview', $activeGrid).length) {
        if ($('.media', $activeGrid).length) {
          $('.grid__content', $activeGrid).css('minHeight', previewHeight > 120 ? previewHeight + 12 : 160);
        }
      }

      $activeGrid.toggleClass('is-info-active');
      if (!$activeGrid.hasClass('is-info-active')) {
        $('.grid__content', $activeGrid).css('minHeight', '');
      }
    }

    // @todo fault proof.
    var $clone = $grid.find('.views-field:not(.views-field-entity-browser-select, .views-field--preview, .views-field--grid-hidden)').clone();

    $clone.each(function () {
      var $field = $(this);
      if ($field.find('.media, img, iframe').length) {
        $field.empty();
      }
    });

    // Remove the views-field class to avoid CSS override.
    // @todo $clone.removeClass('views-field').addClass('views-field--cloned');
    // Add a button to toggle the grid info.
    if (!$('.button-group--grid', grid).length) {
      $grid.append('<div class="button-group button-wrap button-group--grid is-button-js"><button class="button button--select" type="button">&#43;</button><button class="button button--info" type="button">?</button></div>');
    }
    // Append the new .grid__info element.
    // @todo if (!$('.grid__info', grid).length) {
    // @todo   $grid.append('<div class="grid__info visible-grid" />');
    // @todo }
    // @todo if (!$('.grid__info .views-field--cloned', grid).length) {
    // @todo $('.grid__info', grid).append($clone);
    // @todo }
    // Events.
    $grid.on('click.sbGridInfo', '.button--info', toggleGridInfo);
    $grid.addClass(_onGrid);
  }

  /**
   * Attaches Slick Browser view behavior to HTML element.
   *
   * @type {Drupal~behavior}
   */
  Drupal.behaviors.slickBrowserView = {
    attach: function (context) {

      var me = Drupal.slickBrowser;
      context = me.context(context);

      me.once(context, _elView, sbView);
      me.once(context, _elGrid, sbGrid);
    }
  };

})(jQuery, Drupal);
